Routine commit
authorCarl N Baldwin <cnb@plane.(none)>
Tue, 18 Oct 2005 02:45:57 +0000 (20:45 -0600)
committerCarl N Baldwin <cnb@plane.(none)>
Tue, 18 Oct 2005 02:45:57 +0000 (20:45 -0600)
main.cc

diff --git a/main.cc b/main.cc
index c930155cae77a6ec538d9f90511da1efd0ee3b1d..89c17429f0338f29891e8c5feb0f0cc4864d678b 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -44,7 +44,7 @@ int populate_set( void *files_v, int, char **vals, char ** ) {
 int main() {
   string file_string;
 
-  file_set current_files;
+  file_set current;
 
   // Parse the list of files on stdin
   do {
@@ -57,7 +57,7 @@ int main() {
       // type perms user group size datemodified name (7 total)
       // f 0600 cnb cnb 424 20051015205340 ./.git/index
       vector<string> vals = split( file_string, ' ', 7 );
-      current_files.insert( new FileData( vals[0][0],
+      current.insert( new FileData( vals[0][0],
             vals[1],
             vals[2],
             vals[3],
@@ -78,8 +78,8 @@ int main() {
   }
 
   char *sqliteErrMsg = 0;
-  file_set previous_files;
-  rc = sqlite3_exec( db, "select * from filedata;", populate_set, &previous_files, &sqliteErrMsg );
+  file_set backed_up;
+  rc = sqlite3_exec( db, "select * from filedata;", populate_set, &backed_up, &sqliteErrMsg );
   if( SQLITE_OK != rc ) {
     cerr << "Problem with database.  Message is..." << endl;
     cerr << sqliteErrMsg << endl;
@@ -87,29 +87,60 @@ int main() {
 
   sqlite3_close( db );
 
-  for( file_set::iterator i = previous_files.begin(); i != previous_files.end(); ++i ) {
+  for( file_set::iterator i = backed_up.begin(); i != backed_up.end(); ++i ) {
     cout << (*i)->getFileName() << endl;
   }
 
-  // Now divide the two sets into three sets (union and set differences)
+  // Now divide the two sets into three sets (new, deleted and updated )
   FileDataPtrCmp cmp;
 
   file_set new_set;
-  set_difference( current_files.begin(),  current_files.end(),
-                  previous_files.begin(), previous_files.end(),
+  set_difference( current.begin(),  current.end(),
+                  backed_up.begin(), backed_up.end(),
                   inserter( new_set, new_set.begin() ),
                   cmp );
 
-  file_set deleted_set;
-  set_difference( previous_files.begin(), previous_files.end(),
-                  current_files.begin(),  current_files.end(),
-                  inserter( deleted_set, deleted_set.begin() ),
+  file_set deleted;
+  set_difference( backed_up.begin(), backed_up.end(),
+                  current.begin(),  current.end(),
+                  inserter( deleted, deleted.begin() ),
                   cmp );
 
-  // previous_files *should* definitely be the first set here
-  file_set common_set;
-  set_difference( previous_files.begin(), previous_files.end(),
-                  current_files.begin(),  current_files.end(),
-                  inserter( common_set, common_set.begin() ),
+  // backed_up should *definitely* be the first set here
+  file_set updated;
+  set_difference( backed_up.begin(), backed_up.end(),
+                  current.begin(),  current.end(),
+                  inserter( updated, updated.begin() ),
                   cmp );
+
+  // Now find the list of files to backup.
+  file_set backup_list;
+
+  // backup all new files
+  copy( new_set.begin(), new_set.end(), inserter( backup_list, backup_list.begin() ) );
+
+  // backup all the already backed-up files that have changed since the last
+  // backup date.
+  for( file_set::iterator i = updated.begin(); i != updated.end(); ++i ) {
+    if( (*i)->getLastBackupDate() < (*i)->getModifiedDate() ) {
+      backup_list.insert( *i );
+    }
+  }
+
+  // Now, sort the backup_list by filesize and build a list of up to SIZE
+
+  //
+  // Now, sort the non-backed-up list my last_backup_date and back-fill
+
+  // Remove deleted files from the database.
+
+  // Now, use the current set to update values in the database.  You should copy
+  // last_backup_date dates from the backed_up set first.  This will get all of
+  // the latest permissions but include the last_backup_date.
+
+  // Now, update the last_backup_date for all of the files that are in the list
+
+  // Clean-up
+  for( file_set::iterator i = backed_up.begin(); i != backed_up.end(); ++i ) { delete *i; }
+  for( file_set::iterator i = current.begin();   i != current.end();   ++i ) { delete *i; }
 }